# Generated by Selenium IDE
import pytest
import time
import json
import sys
import subprocess
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.common.action_chains import ActionChains
from selenium.webdriver.support import expected_conditions
from selenium.webdriver.support.wait import WebDriverWait
from selenium.webdriver.common.keys import Keys
from selenium.webdriver.common.desired_capabilities import DesiredCapabilities

class TestTest01():
  def setup_method(self, method):
    self.driver = webdriver.Chrome()
    self.vars = {}
  
  def teardown_method(self, method):
    self.driver.quit()
  
  def test_test01(self):
    #a = subprocess.check_output(['jupyter server list'], shell=True)
    #print("The jupyter server:", a)
    #url = a.split(b'\n')[1].decode("utf-8").split(' ')[0]
    self.driver.get("http://localhost:8888")
    self.driver.set_window_size(1500, 1000)
    #self.driver.execute_script("window.scrollTo(0, 200)")
    time.sleep(10)

    self.driver.save_screenshot("jupyterlab-extension1.png")

    try:
        self.driver.find_element(By.CSS_SELECTOR, ".jp-LauncherCard:nth-child(5) svg").click()
    except:
        pass

    time.sleep(5)
    self.driver.save_screenshot("jupyterlab-extension2.png")

    try:
        element = self.driver.find_element(By.XPATH, "//span[text()='binder']")
        actions = ActionChains(self.driver)
        actions.double_click(element).perform()
    except Exception as e:
        print("----------------------------")
        print("----------------------------")
        print(e)
        print("----------------------------")
        pass
    
    time.sleep(5)
    self.driver.save_screenshot("jupyterlab-extension3.png")

    try:
        elements = self.driver.find_elements(By.CLASS_NAME, "makeStyles-iconButton-10")
        for el in elements:
            el.click()
            time.sleep(3)
    except Exception as e:
        print("----------------------------")
        print("----------------------------")
        print(e)
        print("----------------------------")
        pass

    time.sleep(5)
    self.driver.save_screenshot("jupyterlab-extension4.png")

test = TestTest01()
test.setup_method('Chrome')
test.test_test01()
test.teardown_method('Chrome')




from pathlib import Path
import re
import sys
from typing import Tuple

from invoke import task


TOP_DIR = Path(__file__).parent.resolve()


def update_file(filename: str, sub_line: Tuple[str, str], strip: str = None):
    """Utility function for tasks to read, update, and write files"""
    with open(filename, "r") as handle:
        lines = [
            re.sub(sub_line[0], sub_line[1], line.rstrip(strip)) for line in handle
        ]

    with open(filename, "w") as handle:
        handle.write("\n".join(lines))
        handle.write("\n")


@task
def update_version(_, version=""):
    """Update package version using SemVer syntax."""
    if version:
        if version.startswith("v"):
            version = version[1:]
        if re.match(r"[0-9]+(\.[0-9]+){2}.*", version) is None:
            sys.exit(
                f"Error: Passed version ({version}) does to match the SemVer format: "
                "Major.Minor.Patch(+ extras)."
            )
    else:
        sys.exit(
            "Please pass --version with a value that complies to the SemVer format: "
            "Major.Minor.Patch(+ extras)."
        )

    update_file(
            TOP_DIR.joinpath("package.json"), (r'"version":.*,', f'"version": "{version}",')
    )

    print(f"Bumped version to {version} !")
